@@ -4,6 +4,7 @@ import logging
 import ssl
 from pathlib import Path
 import xml.etree.ElementTree as ET
+from typing import Dict
 
 import aiofiles
 from bs4 import BeautifulSoup
@@ -44,6 +45,14 @@ class Session:
                     soup = BeautifulSoup(text, 'html.parser')
                     return soup
 
+    async def get_BS4_and_url(self, url: URL):
+        async with self.client.simultaneous_session_limit:
+            async with self.rate_limiter:
+                async with self.client_session.get(url, ssl=self.client.ssl_context) as response:
+                    text = await response.text()
+                    soup = BeautifulSoup(text, 'html.parser')
+                    return soup, URL(response.url)
+
     async def get_text(self, url: URL):
         async with self.client.simultaneous_session_limit:
             async with self.rate_limiter:
@@ -66,7 +75,7 @@ class Session:
                     xmlTree = ET.fromstring(text)
                     return xmlTree
 
-    async def post_no_resp(self, url: URL, headers: dict):
+    async def get_no_resp(self, url: URL, headers: dict):
         async with self.client.simultaneous_session_limit:
             async with self.rate_limiter:
                 async with self.client_session.get(url, headers=headers, ssl=self.client.ssl_context) as response:
@@ -101,6 +110,13 @@ class DownloadSession:
                                                     cookie_jar=self.client.cookies, timeout=self.timeouts)
         self.throttle_times = {}
 
+    async def get_json_filename(self, url: URL, current_throttle: int, element: str):
+        headers = {'user-agent': self.client.user_agent}
+        await throttle(self, current_throttle, url.host)
+        async with self.client_session.get(url, headers=headers, ssl=self.client.ssl_context) as resp:
+            json_obj = json.loads(await resp.content.read())
+            return json_obj[element]
+
     async def get_filename(self, url: URL, referer: str, current_throttle: int):
         headers = {'Referer': referer, 'user-agent': self.client.user_agent}
         await throttle(self, current_throttle, url.host)
@@ -127,8 +143,9 @@ class DownloadSession:
 
     async def download_file(self, url: URL, referer: str, current_throttle: int, range_num: str, original_filename: str,
                             filename: str, temp_file: str, resume_point: int, show_progress: bool,
-                            File_Lock: FileLock, folder: Path, title: str, proxy: str):
-        headers = {'Referer': referer, 'user-agent': self.client.user_agent}
+                            File_Lock: FileLock, folder: Path, title: str, proxy: str, headers: Dict):
+        headers['Referer'] = referer
+        headers['user-agent'] = self.client.user_agent
         if range_num:
             headers['Range'] = range_num
         await throttle(self, current_throttle, url.host)
