@@ -43,6 +43,7 @@ def parse_args():
     parser.add_argument("--proxy", help="HTTP/HTTPS proxy used for downloading, format [protocal]://[ip]:[port]", default=None)
     parser.add_argument("--separate-posts", help="Separates forum scraping into folders by post number", action="store_true")
     parser.add_argument("--mark-downloaded", help="Sets the scraped files as downloaded without downloading", action="store_true")
+    parser.add_argument("--pixeldrain-api-key", type=str, help="api key for premium pixeldrain", default=None)
     parser.add_argument("--xbunker-username", type=str, help="username to login to xbunker", default=None)
     parser.add_argument("--xbunker-password", type=str, help="password to login to xbunker", default=None)
     parser.add_argument("--socialmediagirls-username", type=str, help="username to login to socialmediagirls", default=None)
@@ -120,7 +121,7 @@ async def download_all(auth_args: Dict, file_args: Dict, jdownloader_args: Dict,
 
     if await content_object.is_empty():
         logging.error('ValueError No links')
-        await log("No links found duing scraping, check passwords or that the urls are accessible", Fore.RED)
+        await log("No links found during scraping, check passwords or that the urls are accessible", Fore.RED)
         await log("This program does not currently support password protected albums.", Fore.RED)
         exit(0)
     await clear()
@@ -160,7 +161,7 @@ async def director(args: argparse.Namespace):
     links = list(map(URL, links))
 
     with open(input_file, "r", encoding="utf8") as f:
-        links += await regex_links(f.read())
+        links += await regex_links([line.rstrip() for line in f])
     links = list(filter(None, links))
 
     if not links:
